bayespy.inference.vmp.nodes.gaussian.GaussianARDDistribution.plates_from_parent
===============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianARDDistribution.plates_from_parent